@@ -29,7 +29,7 @@ from .models.request_data import GitHubBaseRequestDataModel
 from .models.response import GitHubResponseModel
 
 STATUS_EXCEPTIONS: Dict[HttpStatusCode, GitHubException] = {
-    HttpStatusCode.RATELIMIT: GitHubRatelimitException,
+    HttpStatusCode.FORBIDDEN: GitHubAuthenticationException,
     HttpStatusCode.UNAUTHORIZED: GitHubAuthenticationException,
     HttpStatusCode.NOT_MODIFIED: GitHubNotModifiedException,
     HttpStatusCode.NOT_FOUND: GitHubNotFoundException,
@@ -120,7 +120,7 @@ class GitHubClient(GitHubBase):
         if response.status == HttpStatusCode.NO_CONTENT:
             return response
 
-        if response.headers.content_type != HttpContentType.TEXT_PLAIN:
+        if HttpContentType.BASE_JSON in str(response.headers.content_type):
             response.data = await result.json()
         else:
             response.data = await result.text()
